'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DateTimePickerHeader = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _semanticUiReact = require('semantic-ui-react');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _utils = require('../utils.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function DateTimePickerHeader(props) {
  var onNextBtnClick = props.onNextBtnClick,
      onPrevBtnClick = props.onPrevBtnClick,
      showedDate = props.showedDate,
      showedRange = props.showedRange,
      showDate = props.showDate,
      showWeeks = props.showWeeks,
      width = props.width;

  var rest = (0, _utils.getUnhandledProps)(DateTimePickerHeader, props);

  var _getWeekDayHeaders = function _getWeekDayHeaders() {
    return (0, _utils.getWeekDays)().map(function (weekDay) {
      return _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        {
          key: weekDay,
          className: 'suir-calendar week-day',
          colSpan: '1' },
        weekDay
      );
    });
  };

  _getWeekDayHeaders.handledProps = [];
  var cellClasses = (0, _classnames2.default)('suir-calendar', 'cell', showWeeks ? '' : 'time-picker-header');

  var buttonClasses = (0, _classnames2.default)('suir-calendar', 'button');

  var getRangeRow = function getRangeRow() {
    var getContent = function getContent() {
      var start = showedRange.start,
          end = showedRange.end;

      if (start && end) {
        return start.format('MMM DD, YYYY') + ' - ' + end.format('MMM DD, YYYY');
      }
      if (start) {
        return start.format('MMMM DD, YYYY') + ' - ' + '. . .';
      }
      return '. . . - . . .';
    };
    return _react2.default.createElement(
      _semanticUiReact.Table.Row,
      null,
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        { className: 'suir-calendar cell', colSpan: '7' },
        getContent()
      )
    );
  };

  getRangeRow.handledProps = [];
  return _react2.default.createElement(
    _semanticUiReact.Table.Header,
    rest,
    showedRange && getRangeRow(),
    _react2.default.createElement(
      _semanticUiReact.Table.Row,
      null,
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        { className: cellClasses, colSpan: '1' },
        _react2.default.createElement(_semanticUiReact.Icon, {
          className: buttonClasses,
          onClick: onPrevBtnClick,
          name: 'chevron left' })
      ),
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        { className: cellClasses, colSpan: (parseInt(width) - 2).toString() },
        showDate ? showedDate.format('MMMM DD, YYYY') : showedDate.format('MMMM YYYY')
      ),
      _react2.default.createElement(
        _semanticUiReact.Table.HeaderCell,
        { className: cellClasses, colSpan: '1' },
        _react2.default.createElement(_semanticUiReact.Icon, {
          className: buttonClasses,
          onClick: onNextBtnClick,
          name: 'chevron right' })
      )
    ),
    showWeeks && _react2.default.createElement(
      _semanticUiReact.Table.Row,
      null,
      _getWeekDayHeaders()
    )
  );
}

DateTimePickerHeader.handledProps = ['className', 'onNextBtnClick', 'onPrevBtnClick', 'showDate', 'showWeeks', 'showedDate', 'showedRange', 'width'];
DateTimePickerHeader.propTypes = {
  onNextBtnClick: _propTypes2.default.func.isRequired,
  onPrevBtnClick: _propTypes2.default.func.isRequired,
  /** Header's width in table columns */
  width: _propTypes2.default.string.isRequired,
  /** calendar shows date of this `moment` */
  showedDate: _propTypes2.default.instanceOf(_moment2.default).isRequired,
  showedRange: _propTypes2.default.shape({
    start: _propTypes2.default.instanceOf(_moment2.default),
    end: _propTypes2.default.instanceOf(_moment2.default)
  }),
  showDate: _propTypes2.default.bool,
  showWeeks: _propTypes2.default.bool,
  className: _propTypes2.default.string
};

DateTimePickerHeader.defaultProps = {
  showDate: false,
  showWeeks: true
};

exports.default = DateTimePickerHeader;
exports.DateTimePickerHeader = DateTimePickerHeader;